#!/usr/bin/python
# TODO: Make coding more python3-ish
from __future__ import (absolute_import, division)
__metaclass__ = type

from ansible.module_utils.basic import AnsibleModule
from ansible.module_utils.koji import KojiDirective

try:
    import libtaskotron.exceptions as exc
    from libtaskotron import check
except ImportError:
    libtaskotron_found = False
else:
    libtaskotron_found = True


def error_handler(mod):
    raise exc.TaskotronError('Unsupported subject type')

def rpm_handler(mod):
    mod.params['action'] = 'download'
    mod.params['koji_build'] = mod.params['taskotron_item']
    kojidirective = KojiDirective()
    data = kojidirective.process(mod)

    return ' '.join(data['downloaded_rpms'])

def infer_subject_handler(mod):
    #FIXME move subject strings to apropriate collection
    if mod.params['taskotron_item_type'] == check.ReportType.KOJI_BUILD:
        return rpm_handler

    return error_handler

def main():
    mod = AnsibleModule(
        argument_spec=dict(
            arch=dict(required=True),
            taskotron_item=dict(required=True),
            taskotron_item_type=dict(required=True),
            target_dir=dict(required=False, default='.')
        )
    )

    # TODO: check args for completeness
    if not libtaskotron_found:
        mod.fail_json(msg="The libtaskotron python module is required")

    subject_handler = infer_subject_handler(mod)
    try:
        subjects = subject_handler(mod)
    except exc.TaskotronError, e:
        mod.fail_json(msg=e.msg)

    mod.exit_json(msg="Successfuly acquired subjects", changed=True, subjects=subjects)


if __name__ == '__main__':
    main()
